==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebPaneHeaderConnectionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneHeaderConnectionEventArgsDescription } from "./WebPaneHeaderConnectionEventArgsDescription";
/**
 * @hidden
 */
var WebPaneHeaderConnectionEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneHeaderConnectionEventArgsDescriptionMetadata, _super);
    function WebPaneHeaderConnectionEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.b = function (a) {
        if (WebPaneHeaderConnectionEventArgsDescriptionMetadata.a == null) {
            WebPaneHeaderConnectionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneHeaderConnectionEventArgsDescriptionMetadata.c(WebPaneHeaderConnectionEventArgsDescriptionMetadata.a);
        }
        if (a.g(WebPaneHeaderConnectionEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(WebPaneHeaderConnectionEventArgsDescriptionMetadata.a);
        WebPaneHeaderConnectionEventArgsDescriptionMetadata.d(a);
    };
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneHeaderConnectionEventArgs");
        a.item("Detail", "ExportedType:WebPaneHeaderConnectionEventArgs");
    };
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.d = function (a) {
        WebPaneHeaderConnectionEventArgsDescriptionMetadata.b(a);
        a.u("WebPaneHeaderConnectionEventArgs", function () { return new WebPaneHeaderConnectionEventArgsDescription(); });
        a.t("WebPaneHeaderConnectionEventArgs", WebPaneHeaderConnectionEventArgsDescriptionMetadata.a);
    };
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.$t = markType(WebPaneHeaderConnectionEventArgsDescriptionMetadata, 'WebPaneHeaderConnectionEventArgsDescriptionMetadata');
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.a = null;
    return WebPaneHeaderConnectionEventArgsDescriptionMetadata;
}(Base));
export { WebPaneHeaderConnectionEventArgsDescriptionMetadata };

==> igniteui-react-core-18.0.0.tgz: package/esm5/lib/WebPaneHeaderConnectionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebPaneHeaderElementDescriptionMetadata } from "./WebPaneHeaderElementDescriptionMetadata";
import { WebPaneHeaderConnectionEventArgsDescription } from "./WebPaneHeaderConnectionEventArgsDescription";
/**
 * @hidden
 */
var WebPaneHeaderConnectionEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneHeaderConnectionEventArgsDescriptionMetadata, _super);
    function WebPaneHeaderConnectionEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.b = function (a) {
        if (WebPaneHeaderConnectionEventArgsDescriptionMetadata.a == null) {
            WebPaneHeaderConnectionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneHeaderConnectionEventArgsDescriptionMetadata.c(WebPaneHeaderConnectionEventArgsDescriptionMetadata.a);
        }
        if (a.g(WebPaneHeaderConnectionEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(WebPaneHeaderConnectionEventArgsDescriptionMetadata.a);
        WebContentPaneDescriptionMetadata.d(a);
        WebPaneHeaderElementDescriptionMetadata.d(a);
    };
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneHeaderConnectionEventArgs");
        a.item("Pane", "ExportedType:WebContentPane");
        a.item("Element", "ExportedType:WebPaneHeaderElement");
    };
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.d = function (a) {
        WebPaneHeaderConnectionEventArgsDescriptionMetadata.b(a);
        a.u("WebPaneHeaderConnectionEventArgs", function () { return new WebPaneHeaderConnectionEventArgsDescription(); });
        a.t("WebPaneHeaderConnectionEventArgs", WebPaneHeaderConnectionEventArgsDescriptionMetadata.a);
    };
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.$t = markType(WebPaneHeaderConnectionEventArgsDescriptionMetadata, 'WebPaneHeaderConnectionEventArgsDescriptionMetadata');
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.a = null;
    return WebPaneHeaderConnectionEventArgsDescriptionMetadata;
}(Base));
export { WebPaneHeaderConnectionEventArgsDescriptionMetadata };
